@@ -1,4 +1,5 @@
 from typing import List, Optional
+
 import re
 import shlex
 import subprocess
@@ -47,13 +48,18 @@ class FileAction:
         command: Optional[str],
         pattern: Optional[re.Pattern],
         max_capture_number: int,
-        dry_run: bool,
+        dry_run: bool = False,
+        shell_escape: bool = False,
     ):
-        self.file_name = file_name
-        self.dry_run = dry_run
-        self.cmd = build_command_line(command, file_name, pattern, max_capture_number) if command is not None else None
+        self.file_name: str = file_name
+        self.shell_escape = shell_escape
+        if self.shell_escape:
+            assert platform.system() != 'Windows'
+            self.file_name = shlex.quote(self.file_name)
+        self.dry_run: bool = dry_run
+        self.cmd: Optional[List[str]] = build_command_line(command, file_name, pattern, max_capture_number) if command is not None else None
 
-    def __call__(self):
+    def __call__(self) -> None:
         if self.cmd is None:
             print("%s" % self.file_name)
             return
@@ -70,7 +76,7 @@ class FileAction:
             sys.exit(exit_code)
 
 
-def make_window_fit_to_screen(window):
+def make_window_fit_to_screen(window: sg.Window) -> None:
     screen_size = sg.Window.get_screen_size()
     size_limit = (screen_size[0] * 4 // 5, screen_size[1] * 4 // 5)
     window_size = window.size
@@ -89,6 +95,7 @@ Options:
   -p PAT, --pattern=PAT     Pattern to filter / capture files.
   -n, --dry-run             Print commands without running.
   -b, --batch               Batch mode. Run command for each file name found in the text file.
+  -e, --shell-escape        Shell-escaping file names in expanding `{0}`.
   --font=NAMESIZE           Specify font name and size, e.g. `"Noto Sans,12"`
   --font-list               Print the fonts installed.
   --theme=THEME             Specify theme [default: LightGray].
@@ -105,7 +112,7 @@ def main():
     batch: bool = args["--batch"]
     pattern_str: Optional[str] = args["--pattern"]
     theme: str = args["--theme"]
-
+    shell_escape: bool = args["--shell-escape"]
     list_fonts: bool = args["--font-list"]
     preview_themes: str = args["--theme-preview"]
 
@@ -147,7 +154,8 @@ def main():
             max_capture_number = max(max_capture_number, n)
 
     def gen_action(file_name):
-        return FileAction(file_name, command, pattern, max_capture_number, dry_run)
+        return FileAction(file_name, command, pattern, max_capture_number,
+                dry_run=dry_run, shell_escape=shell_escape)
 
     if textfile is not None:
         with open(textfile, "r") as inp:
